@@ -20,11 +20,11 @@ class StateMachineStrategy(Strategy):
         self.state = self.recover_state() or self.initial_state()
 
     def on_event(self, event: Event):
+        logging.debug("Event: %s: %s" % (event.__class__.__name__, event.payload))
         super().on_event(event)
         if self.prev != self.state:
-            logging.debug("StateMachineStrategy.on_event(%s), state: %s" % (str(event.__class__), self.state))
+            logging.debug("State change: %s -> %s" % (self.prev, self.state))
             self.prev = self.state
-        logging.debug("Event: %s: %s" % (event.__class__.__name__, event.payload))
         self.state = self.state.on_event(StrategyEvent(event, self))
 
     def recover_state(self):
